/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import LightDM 0.1 as LightDM
import "../Components"

MouseArea {
    id: root
    anchors.fill: parent

    property bool promptless: loginLoader.status == Loader.Ready && LightDM.Greeter.promptless
    property bool ready: wallpaper.status == Image.Ready
    property alias leftTeaserPressed: leftTeaser.pressed

    signal selected(int uid)
    signal unlocked(int uid)

    CrossFadeImage {
        id: wallpaper

        source: shell.background
        anchors.fill: parent
        crossFade: false
        fadeInFirst: false
    }

    Rectangle {
        anchors.fill: parent
        color: "black"
        opacity: 0.4
    }

    Clock {
        id: clock
        visible: narrowMode

        anchors {
            top: parent.top
            topMargin: units.gu(2)
            horizontalCenter: parent.horizontalCenter
        }
    }

    MouseArea {
        id: leftTeaser
        anchors.fill: parent
        anchors.rightMargin: parent.width / 2
    }

    Loader {
        id: loginLoader
        objectName: "loginLoader"
        anchors {
            left: parent.left
            leftMargin: Math.min(parent.width * 0.16, units.gu(20))
            verticalCenter: parent.verticalCenter
        }
        width: units.gu(29)
        height: parent.height

        source: greeter.multiUser ? "LoginList.qml" : ""

        onLoaded: {
            item.currentIndex = greeterContentLoader.currentIndex
        }

        Binding {
            target: loginLoader.item
            property: "model"
            value: greeterContentLoader.model
        }

        Connections {
            target: loginLoader.item

            onSelected: {
                root.selected(uid);
            }

            onUnlocked: {
                root.unlocked(uid);
            }

            onCurrentIndexChanged: {
                greeterContentLoader.currentIndex = loginLoader.item.currentIndex;
            }
        }
    }

    // FIXME: The images are way bigger than their content because the infographic
    // bubbles can grow a lot. Because of that the infographic image reaches under the
    // login list. This code makes sure that it never really overlaps until unusable
    // with the current artwork. Will be replaced by real infographic.
    CrossFadeImage {
        id: infographics
        width: narrowMode ? sourceSize.width : Math.min(parent.width - loginLoader.x - loginLoader.width/2, units.gu(90))
        height: narrowMode ? sourceSize.height : width * 8/9

        anchors {
            verticalCenter: parent.verticalCenter
            horizontalCenter: narrowMode ? parent.horizontalCenter : undefined
            right: narrowMode ? undefined : parent.right
            rightMargin: narrowMode ? 0 : units.gu(-6)
        }
        source: narrowMode ? "graphics/infographic_tweeter_cut.png" : loginLoader.item.userList.model.data(currentIndex, LightDM.UserRoles.InfographicRole) ? loginLoader.item.userList.model.data(currentIndex, LightDM.UserRoles.InfographicRole) : ""
    }
}
