/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
 */

#include "MouseTouchAdaptor.h"

#include <qpa/qwindowsysteminterface.h>

#include <QtGui/QMouseEvent>
#include <QtTest/QTest>

using QTest::QTouchEventSequence;

MouseTouchAdaptor::MouseTouchAdaptor(QObject *parent)
    : QObject(parent)
    , m_targetWindow(0)
{
    m_touchDevice = new QTouchDevice;
    m_touchDevice->setType(QTouchDevice::TouchScreen);
    QWindowSystemInterface::registerTouchDevice(m_touchDevice);
}

void MouseTouchAdaptor::setTargetWindow(QWindow *window)
{
    m_targetWindow = window;
}

bool MouseTouchAdaptor::eventFilter(QObject *, QEvent *event)
{
    Q_ASSERT(m_targetWindow);

    if (event->type() == QEvent::MouseButtonPress) {
        return handleMousePress(static_cast<QMouseEvent*>(event));
    } else if (event->type() == QEvent::MouseMove) {
        return handleMouseMove(static_cast<QMouseEvent*>(event));
    } else if (event->type() == QEvent::MouseButtonRelease) {
        return handleMouseRelease(static_cast<QMouseEvent*>(event));
    } else {
        return false;
    }
}

bool MouseTouchAdaptor::handleMousePress(QMouseEvent *mouseEvent)
{
    // Just eat the event if it wasn't a left mouse press
    if (mouseEvent->button() != Qt::LeftButton)
        return true;

    QTouchEventSequence touchEvent = QTest::touchEvent(m_targetWindow, m_touchDevice,
                                                       false /* autoCommit */);
    touchEvent.press(0 /* touchId */, mouseEvent->windowPos().toPoint());
    touchEvent.commit(false /* processEvents */);

    return true;
}

bool MouseTouchAdaptor::handleMouseMove(QMouseEvent *mouseEvent)
{
    // Just eat the event if left button isn't pressed
    if (!(mouseEvent->buttons() & Qt::LeftButton))
        return true;

    QTouchEventSequence touchEvent = QTest::touchEvent(m_targetWindow, m_touchDevice,
                                                       false /* autoCommit */);
    touchEvent.move(0 /* touchId */, mouseEvent->windowPos().toPoint());
    touchEvent.commit(false /* processEvents */);

    return true;
}

bool MouseTouchAdaptor::handleMouseRelease(QMouseEvent *mouseEvent)
{
    // Just eat the event if it wasn't a left button release
    if (mouseEvent->button() != Qt::LeftButton)
        return true;

    QTouchEventSequence touchEvent = QTest::touchEvent(m_targetWindow, m_touchDevice,
                                                       false /* autoCommit */);
    touchEvent.release(0 /* touchId */, mouseEvent->windowPos().toPoint());
    touchEvent.commit(false /* processEvents */);

    return true;
}
