/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
 */

#ifndef MOUSE_TOUCH_ADAPTOR_H
#define MOUSE_TOUCH_ADAPTOR_H

#include <QtCore/QObject>

class QMouseEvent;
class QTouchDevice;
class QWindow;

// Transforms QMouseEvents into single-finger QTouchEvents.
class MouseTouchAdaptor : public QObject {
    Q_OBJECT

public:
    MouseTouchAdaptor(QObject *parent = 0);

    // The window that will receive the generated QTouchEvents
    void setTargetWindow(QWindow *window);

    // Filters QMouseEvents and posts the equivalent QTouchEvents.
    virtual bool eventFilter(QObject *watched, QEvent *event);

private:
    bool handleMousePress(QMouseEvent *mouseEvent);
    bool handleMouseMove(QMouseEvent *mouseEvent);
    bool handleMouseRelease(QMouseEvent *mouseEvent);

    QWindow *m_targetWindow;
    QTouchDevice *m_touchDevice;
};

#endif // MOUSE_TOUCH_ADAPTOR_H
